@@ -1,3 +1,6 @@
+from pacroller.config import KNOWN_OUTPUT_OVERRIDE
+KNOWN_HOOK_OUTPUT_OVERRIDE, KNOWN_PACKAGE_OUTPUT_OVERRIDE = KNOWN_OUTPUT_OVERRIDE
+
 KNOWN_HOOK_OUTPUT = {
     '': [],
     '20-systemd-sysusers.hook': [
@@ -15,7 +18,8 @@ KNOWN_HOOK_OUTPUT = {
         r'==> Creating (?:.+)-compressed initcpio image: .+',
         r'==> Image generation successful.*',
         r'[ ]+-> .+',
-    ]
+    ],
+    **KNOWN_HOOK_OUTPUT_OVERRIDE
 }
 
 _keyring_output = [
@@ -41,4 +45,10 @@ KNOWN_PACKAGE_OUTPUT = {
     'brltty': [
         r'Please add your user to the brlapi group\.',
     ],
+    'glibc': [
+        r'Generating locales\.\.\.',
+        r'Generation complete\.',
+        r'  .*_.*\.\.\. done',
+    ],
+    **KNOWN_PACKAGE_OUTPUT_OVERRIDE
 }
